# source this file to access LALApps
export LALAPPS_PREFIX
LALAPPS_PREFIX="/Users/ram/git/lalsuite/_inst"
export PYTHONPATH
PYTHONPATH=`echo "$PYTHONPATH" | /opt/local/bin/gsed -e 's|/Users/ram/git/lalsuite/_inst/lib/python2.7/site-packages:||g;'`
PYTHONPATH="/Users/ram/git/lalsuite/_inst/lib/python2.7/site-packages:$PYTHONPATH"
export PATH
PATH=`echo "$PATH" | /opt/local/bin/gsed -e 's|/Users/ram/git/lalsuite/_inst/bin:||g;'`
PATH="/Users/ram/git/lalsuite/_inst/bin:$PATH"
export LALAPPS_DATADIR
LALAPPS_DATADIR="/Users/ram/git/lalsuite/_inst/share/lalapps"
export MANPATH
MANPATH=`echo "$MANPATH" | /opt/local/bin/gsed -e 's|/Users/ram/git/lalsuite/_inst/share/man:||g;'`
MANPATH="/Users/ram/git/lalsuite/_inst/share/man:$MANPATH"
